From 60d9c79f910bb655f08ab39d7fb7fe1ded7a6753 Mon Sep 17 00:00:00 2001
From: thomascube <thomas@roundcube.net>
Date: Tue, 08 May 2012 06:12:44 -0400
Subject: [PATCH] Fix handling of 'serialzied' LDAP address attributes

---
 program/include/rcube_message.php |   10 ++++++----
 1 files changed, 6 insertions(+), 4 deletions(-)

diff --git a/program/include/rcube_message.php b/program/include/rcube_message.php
index 76246a2..58f8510 100644
--- a/program/include/rcube_message.php
+++ b/program/include/rcube_message.php
@@ -164,11 +164,13 @@
     /**
      * Get content of a specific part of this message
      *
      * @param string $mime_id Part MIME-ID
      * @param resource $fp File pointer to save the message part
      * @return string Part content
      */
-    public function get_part_content($mime_id, $fp=NULL)
+    public function get_part_content($mime_id, $fp = null, $skip_charset_conv = false)
     {
         if ($part = $this->mime_parts[$mime_id]) {
             // stored in message structure (winmail/inline-uuencode)
@@ -179,7 +181,7 @@
                 return $fp ? true : $part->body;
             }
             // get from IMAP
-            return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp);
+            return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp, $skip_charset_conv);
         } else
             return null;
     }
@@ -164,11 +164,13 @@
      * Get content of a specific part of this message
      *
-     * @param string $mime_id Part MIME-ID
-     * @param resource $fp File pointer to save the message part
+     * @param string   $mime_id           Part MIME-ID
+     * @param resource $fp File           pointer to save the message part
+     * @param boolean  $skip_charset_conv Disables charset conversion
+     *
      * @return string Part content
      */

--
Gitblit v1.9.1